@@ -5,6 +5,8 @@ use warnings;
 
 use parent 'PLS::Server::Request';
 
+use Coro;
+
 use PLS::Parser::Document;
 use PLS::Server::Request::Diagnostics::PublishDiagnostics;
 
@@ -26,7 +28,7 @@ sub service
     my $text_document = $self->{params}{textDocument};
     PLS::Parser::Document->open_file(%{$text_document});
 
-    $server->send_server_request(PLS::Server::Request::Diagnostics::PublishDiagnostics->new(uri => $self->{params}{textDocument}{uri}));
+    $server->{server_requests}->put(PLS::Server::Request::Diagnostics::PublishDiagnostics->new(uri => $self->{params}{textDocument}{uri}));
 
     return;
 } ## end sub service
